/*
video.c -- graphical frontend
Copyright (C) 2005  Martin Wolters

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the 

Free Software Foundation, Inc.
51 Franklin Street, Fifth Floor
Boston, MA  02110-1301
USA

You can contact the author via electronic mail by the address
'nc-wolterma4@netcologne.de'.
*/

#include <SDL.h>
#include <SDL_ttf.h>
#include <unistd.h>

#include "video.h"
#include "fs.h"

SDL_Surface *dVidInit(void) {
	SDL_Surface *dWindow;

//	printf("Initializing SDL...\n");
#ifdef GP2X
	if(SDL_Init(SDL_INIT_VIDEO | SDL_INIT_JOYSTICK) < 0) {
#else
	if(SDL_Init(SDL_INIT_VIDEO) < 0) {
#endif
		printf("Could not initialize SDL. Error: %s\n", SDL_GetError());
		return NULL;
	}
#ifdef GP2X
	SDL_ShowCursor(0);
	SDL_JoystickOpen(0);
#endif
	
//	printf("Creating Window...\n");
	dWindow = SDL_SetVideoMode(320, 240, 8, SDL_SWSURFACE | SDL_ANYFORMAT);
	if(!dWindow) {
		printf("Could not create window. Error: %s\n", SDL_GetError());
		return NULL;
	}
	
	return dWindow;
}

TTF_Font *fFontInit(char *cFontFile) {
	TTF_Font *fFont;
		
//	printf("Initializing TTF...\n");
	if(TTF_Init() < 0) {
		printf("Could not initialize TTF. Error: %s\n", TTF_GetError());
		return NULL;
	}

//	printf("Loading Font '%s'...\n", cFontFile);
	fFont = TTF_OpenFont(cFontFile, SIZE);
	if(fFont == NULL) {
		printf("Could not load '%s'. Error: %s\n", cFontFile, TTF_GetError());
		return NULL;
	}

	return fFont;
}

int iUpdateScrn(INFO *sInfo, DIRINFO *sDirInfo) {
	int i, j;
	SDL_Color sColor = sInfo->sBgCol;
	SDL_Color sWdCol = {163, 146, 88};
	SDL_Rect sPos = {0,0,320,SIZE * 1.5};
	
	SDL_FillRect(sInfo->dWindow, NULL,
		SDL_MapRGB(sInfo->dWindow->format, sColor.r, sColor.g, sColor.b));
	SDL_FillRect(sInfo->dWindow, &sPos,
		SDL_MapRGB(sInfo->dWindow->format, 240, 232, 139));

	sInfo->iColumn = 3;
	sInfo->iLine = 0;
	iWriteText(sDirInfo->cWorkingDir, sInfo, sWdCol);
	
	j = sInfo->iWndLine + 240 / SIZE;
	if(j > sDirInfo->iNumFiles)
		j = sDirInfo->iNumFiles;

	for(i = sInfo->iWndLine; i < j; i++) {
		sInfo->iLine = STARTLIN + i - sInfo->iWndLine;
		sColor = sInfo->sFnCol[sDirInfo->iFileType[i]];
		iWriteText(sDirInfo->cFileName[i], sInfo, sColor);
	}
	
	sInfo->iLine = sInfo->iCurLine;
	sInfo->iColumn = 0;
	sColor=sInfo->sFnCol[TYPE_DIR];
	iWriteText("->", sInfo, sColor);

	return 1;
}

int iWriteText(char *cText, INFO *sInfo, SDL_Color sColor) {
	SDL_Surface *sTextSurface;
	SDL_Rect sPos = {sInfo->iColumn * 10, (sInfo->iLine * SIZE)};

	sTextSurface = TTF_RenderText_Solid(sInfo->fFont, cText, sColor);
	if(!sTextSurface) {
//		printf("Could not render Text. Error: %s\n", TTF_GetError());
		return 0;
	} else {
		SDL_BlitSurface(sTextSurface, NULL, sInfo->dWindow, &sPos);
		SDL_Flip(sInfo->dWindow);
	}
	return 1;
}

int iVidStop(void) {
//#ifdef GP2X
	chdir("/usr/gp2x");
	execl("/usr/gp2x/gp2xmenu", "/usr/gp2x/gp2xmenu", NULL); 
//#endif
	SDL_Quit();

	return 1;
}

/*)\
\(*/
